@@ -1,6 +1,6 @@
 /*
  *  cryptmount - a utility for user-level mounting of encrypted filesystems
- *  (C)Copyright 2005-2014, RW Penney
+ *  (C)Copyright 2005-2015, RW Penney
  */
 
 /*
@@ -1057,7 +1057,7 @@ static void check_priv_opt(const char *opt)
     }
 
     /* Remove effect of any setuid flags, reverting to real user-id: */
-    seteuid(getuid());
+    if (seteuid(getuid()) != 0) exit(EXIT_PRIV);
 }
 
 
@@ -1185,11 +1185,16 @@ static int execute_list(cmmode_t mode, const tgtdefn_t *tgttable,
             default:
                 break;
         }
-#if defined(HAVE_SYSLOG) && !defined(TESTING)
+#ifndef TESTING
+#  ifdef HAVE_SYSLOG
         if (syslogmsg != NULL) {
             syslog(prio, syslogmsg, elt->tgt->ident, username,
                 (eflag == ERR_NOERROR ? "succeeded" : "failed"));
         }
+#  endif
+#else   /* TESTING */
+        /* Avoid compiler warnings about unused variables: */
+        eflag += 0 * (prio + (username == NULL) + (syslogmsg == NULL));
 #endif
 
         free_boundtgt(boundtgt);
@@ -1556,5 +1561,5 @@ int main(int argc, char *argv[])
 }
 
 /*
- *  (C)Copyright 2005-2014, RW Penney
+ *  (C)Copyright 2005-2015, RW Penney
  */
