@@ -1,6 +1,6 @@
 /*
  *  Filesystem-related utilities for cryptmount
- *  (C)Copyright 2005-2014, RW Penney
+ *  (C)Copyright 2005-2015, RW Penney
  */
 
 /*
@@ -579,7 +579,7 @@ static int run_sucommand(const char *path, const char **argv,
             if ((switches & F_MATCHUID) != 0) {
                 /* change real UID to match effective UID
                    (probably only useful if euid==root): */
-                (void)setuid(geteuid());
+                if (setuid(geteuid()) != 0) exit(EXIT_BADEXEC);
             }
             if ((switches & F_CLOSE1) != 0) {
                 /* redirect standard output to /dev/null */
@@ -696,5 +696,5 @@ int fs_test_entropy()
 #endif  /* TESTING */
 
 /*
- *  (C)Copyright 2005-2014, RW Penney
+ *  (C)Copyright 2005-2015, RW Penney
  */
