@@ -1,6 +1,6 @@
 /*
  *  Config-table and mount-table utilities for cryptmount
- *  (C)Copyright 2005-2014, RW Penney
+ *  (C)Copyright 2005-2015, RW Penney
  */
 
 /*
@@ -487,8 +487,9 @@ static void read_token(char *buff, unsigned *t_state, tgtdefn_t *tgt)
                             proc_string,    NULL },
         { "mountoptions",   OFFSET(mountoptions),
                             proc_string,    NULL },
+    /* FIXME - "fsoptions" was deprecated in version 4.1 - remove by Jan2016 */
         { "fsoptions",      OFFSET(mountoptions),
-                            proc_string,    NULL },  /* Deprecated since 4.1 */
+                            proc_string,    NULL },
         { "fsckoptions",    OFFSET(fsckoptions),
                             proc_string,    NULL },
         { "loop",           OFFSET(loopdev),
@@ -999,5 +1000,5 @@ int is_cmstatus_intact()
 }
 
 /*
- *  (C)Copyright 2005-2014, RW Penney
+ *  (C)Copyright 2005-2015, RW Penney
  */
